float4x4 World;
float4x4 View;
float4x4 Projection;
float4x4 WorldInverseTranspose;

float4 AmbientColor = float4(1,1,1,1);
float4 AmbientIntensity = 0.1;
float4 DiffuseLightDirection = float4(0, 0, 1, 0);
float4 DiffuseColor = float4(1,1,1,1);
float4 CamPos;

struct VS_IN
{
	float4 Position : POSITION;
	float4 Normal: NORMAL;
};

struct VS_OUT
{
	float4 Position : SV_POSITION;
	float4 Color: COLOR0;
};

VS_OUT VS(VS_IN input) 
{
	VS_OUT output = (VS_OUT)0;

	float4 worldPosition = mul(input.Position, World);
	float4 viewPosition = mul(worldPosition, View);
	output.Position = mul(viewPosition, Projection);

	float4 normal = mul(input.Normal, WorldInverseTranspose);
	float lightIntensity = dot(normal, DiffuseLightDirection);	
	
	output.Color = 0.5 * DiffuseColor * lightIntensity 	+ DiffuseColor ;
	
	return output;
}

float4 PS( VS_OUT input ): SV_Target
{
	return saturate(input.Color + AmbientColor * AmbientIntensity);
}

technique10 Render
{
	pass P0
	{
		SetGeometryShader( 0 );
		SetVertexShader( CompileShader( vs_4_0, VS() ) );
		SetPixelShader( CompileShader( ps_4_0, PS() ) );
	}
}