float4x4 World;
float4x4 View;
float4x4 Projection;
float4x4 WorldInverseTranspose;

float4 DiffuseLightDirection = float4(0, 0, 1, 0);
float4 DiffuseLightCoDirectionA = float4(0,  1, 0, 0);

float4 DiffuseColor = float4(1,1,1,1);
float4 CamPos;


struct VS_IN
{
	float4 Position : POSITION;
	float4 Normal: NORMAL;
};

struct VS_OUT
{
	float4 Position : SV_POSITION;
	float3 Light: TEXCOORD0;
	float3 Norm: TEXCOORD1;
	float3 View: TEXCOORD2;
};


VS_OUT VS(VS_IN input) 
{
	VS_OUT output = (VS_OUT)0;

	float4 worldPosition = mul(input.Position, World);
	float4 viewPosition = mul(worldPosition, View);
	
	output.Position = mul(viewPosition, Projection);
	output.Light = DiffuseLightDirection;
	output.View = CamPos - output.Light.xyz;

	float4 normal = mul(input.Normal, WorldInverseTranspose);
	output.Norm = normal;
	
	return output;
}

float4 PS( VS_OUT input ): SV_Target
{
	float3 normal = normalize(input.Norm);
	float3 viewDir = normalize(input.View);
	float3 lightDir = normalize(input.Light);

	float lightIntensity = dot(normal, DiffuseLightDirection);	
	float lightIntensityCoA = dot(normal, DiffuseLightCoDirectionA);
	
	float3 reflect = normalize(2* lightIntensity * normal - lightDir);
	float4 specular = pow(dot(reflect, viewDir), 8);
		
	float4 Color = saturate(DiffuseColor  * lightIntensity);

	return saturate(Color + 0.4*specular + 0.2*DiffuseColor);	
}

technique10 Render
{
	pass P0
	{
		SetGeometryShader( 0 );
		SetVertexShader( CompileShader( vs_4_0, VS() ) );
		SetPixelShader( CompileShader( ps_4_0, PS() ) );
	}
}